<?php
/**
 * @file
 * Metatag integration for the Metatag:Cxense module.
 */

/**
 * Implements hook_metatag_bundled_config_alter().
 */
function metatag_cxense_metatag_bundled_config_alter(array &$configs) {
  foreach ($configs as &$config) {
    switch ($config->instance) {
      case 'node':
        $config->config += array(
          'cXenseParse:recs:publishtime' => array('value' => '[node:created:custom:Y-m-d\TH:i:sP]'),
        );
        break;
    }
  }
}

/**
 * Implements hook_metatag_info().
 */
function metatag_cxense_metatag_info() {
  $info['groups']['cxense'] = array(
    'label' => t('Cxense'),
    'description' => t("Meta tags used to integrate with Cxense's APIs. They are primarily of benefit for sites using Cxense Insight."),
    'form' => array(
      '#weight' => 75,
    ),
  );

  // Cxense meta tags stack after the simple tags.
  $weight = 30;

  // Default values for each meta tag.
  $tag_info_defaults = array(
    'description' => '',
    'class' => 'DrupalTextMetaTag',
    'group' => 'cxense',
    'element' => array(
      '#theme' => 'metatag',
    ),
  );

  $info['tags']['cXenseParse:articleid'] = array(
    'label' => t('Cxsense Article ID'),
    'description' => t('Unique ID of the article.'),
    'weight' => ++$weight,
    'devel_generate' => array(
      'type' => 'integer',
    ),
  ) + $tag_info_defaults;
  
  $info['tags']['cXenseParse:image'] = array(
    'label' => t('Cxsense Images'),
    'description' => t('Image URL of the content.'),
    'weight' => ++$weight,
    'devel_generate' => array(
      'type' => 'string',
    ),
  ) + $tag_info_defaults;
  
  $info['tags']['cXenseParse:category'] = array(
    'label' => t('Cxsense Category'),
    'description' => t('Hierarchical category list of the content, multiple must be seperated by slashes. <br>For instance, a valid option would be Verhicles/Cars/Toyota'),
    'weight' => ++$weight,
    'devel_generate' => array(
      'type' => 'string',
    ),
  ) + $tag_info_defaults;
  
  $info['tags']['cXenseParse:taxonomy'] = array(
    'label' => t('Cxsense Taxonomy'),
    'description' => t('Hierarchical taxonomy of the content, multiple must be seperated by slashes. <br>For instance, a valid option would be Verhicles/Cars/Toyota'),
    'weight' => ++$weight,
    'devel_generate' => array(
      'type' => 'string',
    ),
  ) + $tag_info_defaults;
  
  $info['tags']['cXenseParse:pageclass'] = array(
    'label' => t('Cxsense Page Class'),
    'description' => t('The class of a page.'),
    'weight' => ++$weight,
    'form' => array(
      '#type' => 'select', 
      '#options' => array(
        'homepage' => 'Homepage', 
        'article' => 'Article', 
      ), 
    ),
    'devel_generate' => array(
      'type' => 'select',
    ),
  ) + $tag_info_defaults;
  
  $info['tags']['cXenseParse:title'] = array(
    'label' => t('Cxsense Title'),
    'description' => t('Title of the content'),
    'weight' => ++$weight,
    'devel_generate' => array(
      'type' => 'string',
    ),
  ) + $tag_info_defaults;
  
  $info['tags']['cXenseParse:author'] = array(
    'label' => t('Cxsense Author'),
    'description' => t('Author of the content'),
    'weight' => ++$weight,
    'devel_generate' => array(
      'type' => 'string',
    ),
  ) + $tag_info_defaults;
  
  $info['tags']['cXenseParse:description'] = array(
    'label' => t('Cxsense Description'),
    'description' => t('Description of the content'),
    'weight' => ++$weight,
    'devel_generate' => array(
      'type' => 'string',
    ),
  ) + $tag_info_defaults;
  
  $info['tags']['cXenseParse:keywords'] = array(
    'label' => t('Cxsense Keywords'),
    'description' => t('Keywords of the content, multiple must be seperated by commas.'),
    'weight' => ++$weight,
    'devel_generate' => array(
      'type' => 'string',
    ),
  ) + $tag_info_defaults;
  
  
  // Cxense meta tags for recommended content.
  $weight = 31;
  
  $info['groups']['cxense_recs'] = array(
    'label' => t('Cxense recommendations'),
    'description' => t("Meta tags used to integrate with Cxense's APIs. They are primarily of benefit for sites using Cxense DMP."),
    'form' => array(
      '#weight' => 76,
    ),
  );
  
  $tag_info_defaults = array(
    'description' => '',
    'class' => 'DrupalTextMetaTag',
    'group' => 'cxense_recs',
    'element' => array(
      '#theme' => 'metatag',
    ),
  );

  $info['tags']['cXenseParse:recs:articleid'] = array(
    'label' => t('Cxsense Article ID'),
    'description' => t('Unique ID of the article.'),
    'weight' => ++$weight,
    'devel_generate' => array(
      'type' => 'integer',
    ),
  ) + $tag_info_defaults;

  $info['tags']['cXenseParse:recs:publishtime'] = array(
    'label' => t('Cxsense Publish Time'),
    'description' => t('The date/time of the publication for this page. Must be in the following format: Y-m-d\TH:i:sP.'),
    'weight' => ++$weight,
    'form' => array(
      '#type' => 'textfield', 
    ),
  ) + $tag_info_defaults;
    
  $info['tags']['cXenseParse:recs:image'] = array(
    'label' => t('Cxsense Images'),
    'description' => t('Image URL of the content.'),
    'weight' => ++$weight,
    'devel_generate' => array(
      'type' => 'string',
    ),
  ) + $tag_info_defaults;
  
  $info['tags']['cXenseParse:recs:category'] = array(
    'label' => t('Cxsense Category'),
    'description' => t('Category of the content, multiple must be seperated by slashes'),
    'weight' => ++$weight,
    'devel_generate' => array(
      'type' => 'string',
    ),
  ) + $tag_info_defaults;
  
  $info['tags']['cXenseParse:recs:taxonomy'] = array(
    'label' => t('Cxsense Taxonomy'),
    'description' => t('Taxonomy of the content, multiple must be seperated by slashes'),
    'weight' => ++$weight,
    'devel_generate' => array(
      'type' => 'string',
    ),
  ) + $tag_info_defaults;
  
  $info['tags']['cXenseParse:recs:recommendable'] = array(
    'label' => t('Cxsense Recommendable'),
    'description' => t('Cxense recommendable setting'),
    // TODO: add more descriptive info here.
    'weight' => ++$weight,
    'form' => array(
      '#type' => 'select', 
      '#options' => array(
        'true' => 'Yes', 
        'false' => 'No', 
      ), 
    ),
    'devel_generate' => array(
      'type' => 'select',
    ),
  ) + $tag_info_defaults;
  
  $info['tags']['cXenseParse:recs:recommending'] = array(
    'label' => t('Cxsense Recommending'),
    'description' => t('Cxense recommending setting'),
    // TODO: add more descriptive info here.
    'weight' => ++$weight,
    'form' => array(
      '#type' => 'select', 
      '#options' => array(
        'true' => 'Yes', 
        'false' => 'No', 
      ), 
    ),
    'devel_generate' => array(
      'type' => 'select',
    ),
  ) + $tag_info_defaults;

  return $info;
}
